==> haskell-uniplate-1.6.13-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uniplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uniplate
version:              1.6.13
visibility:           public
id:                   uniplate-1.6.13-CVLl722d0IL3Zqn7ioUsB6
key:                  uniplate-1.6.13-CVLl722d0IL3Zqn7ioUsB6
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/uniplate#readme
synopsis:             Help writing simple, concise and fast generic operations.
description:
    Uniplate is library for writing simple and concise generic operations.
    Uniplate has similar goals to the original Scrap Your Boilerplate work,
    but is substantially simpler and faster.

    To get started with Uniplate you should import one of the three following
    modules:

    * "Data.Generics.Uniplate.Data" - to quickly start writing generic functions.
    Most users should start by importing this module.

    * "Data.Generics.Uniplate.Direct" - a replacement for "Data.Generics.Uniplate.Data"
    with substantially higher performance (around 5 times), but requires writing
    instance declarations.

    * "Data.Generics.Uniplate.Operations" - definitions of all the operations defined
    by Uniplate. Both the above two modules re-export this module.

    In addition, some users may want to make use of the following modules:

    * "Data.Generics.Uniplate.Zipper" - a zipper built on top of Uniplate instances.

    * "Data.Generics.SYB" - users transitioning from the Scrap Your Boilerplate library.

    * "Data.Generics.Compos" - users transitioning from the Compos library.

    * "Data.Generics.Uniplate.DataOnly" - users making use of both @Data@ and @Direct@
    to avoid getting instance conflicts.

category:             Generics
abi:                  d1342d6ad0e13653f68f3861390ea43e
exposed:              True
exposed-modules:
    Data.Generics.Biplate Data.Generics.Compos Data.Generics.PlateData
    Data.Generics.PlateDirect Data.Generics.PlateTypeable
    Data.Generics.SYB Data.Generics.Str Data.Generics.Uniplate
    Data.Generics.Uniplate.Data Data.Generics.Uniplate.Data.Instances
    Data.Generics.Uniplate.DataOnly Data.Generics.Uniplate.Direct
    Data.Generics.Uniplate.Operations Data.Generics.Uniplate.Typeable
    Data.Generics.Uniplate.Zipper Data.Generics.UniplateOn
    Data.Generics.UniplateStr Data.Generics.UniplateStrOn

hidden-modules:
    Data.Generics.Uniplate.Internal.Data
    Data.Generics.Uniplate.Internal.DataOnlyOperations
    Data.Generics.Uniplate.Internal.Utils

import-dirs:          /usr/lib/ghc-8.10.2/site-local/uniplate-1.6.13
library-dirs:         /usr/lib/ghc-8.10.2/site-local/uniplate-1.6.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/uniplate-1.6.13
hs-libraries:         HSuniplate-1.6.13-CVLl722d0IL3Zqn7ioUsB6
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1
    hashable-1.3.0.0-64AyhGQ2yLm2m4iaj2rNmL
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp
    unordered-containers-0.2.13.0-1fMD3PkUAk53GqTppiBvYp

haddock-interfaces:   /usr/share/doc/haskell-uniplate/html/uniplate.haddock
haddock-html:         /usr/share/doc/haskell-uniplate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uniplate-1.6.13-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uniplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uniplate
version:              1.6.13
visibility:           public
id:                   uniplate-1.6.13-4aXpbfPDqvTD2bjR5AQQUf
key:                  uniplate-1.6.13-4aXpbfPDqvTD2bjR5AQQUf
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2020
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/uniplate#readme
synopsis:             Help writing simple, concise and fast generic operations.
description:
    Uniplate is library for writing simple and concise generic operations.
    Uniplate has similar goals to the original Scrap Your Boilerplate work,
    but is substantially simpler and faster.

    To get started with Uniplate you should import one of the three following
    modules:

    * "Data.Generics.Uniplate.Data" - to quickly start writing generic functions.
    Most users should start by importing this module.

    * "Data.Generics.Uniplate.Direct" - a replacement for "Data.Generics.Uniplate.Data"
    with substantially higher performance (around 5 times), but requires writing
    instance declarations.

    * "Data.Generics.Uniplate.Operations" - definitions of all the operations defined
    by Uniplate. Both the above two modules re-export this module.

    In addition, some users may want to make use of the following modules:

    * "Data.Generics.Uniplate.Zipper" - a zipper built on top of Uniplate instances.

    * "Data.Generics.SYB" - users transitioning from the Scrap Your Boilerplate library.

    * "Data.Generics.Compos" - users transitioning from the Compos library.

    * "Data.Generics.Uniplate.DataOnly" - users making use of both @Data@ and @Direct@
    to avoid getting instance conflicts.

category:             Generics
abi:                  852af6489afbb78b12690df4db2e0c6f
exposed:              True
exposed-modules:
    Data.Generics.Biplate Data.Generics.Compos Data.Generics.PlateData
    Data.Generics.PlateDirect Data.Generics.PlateTypeable
    Data.Generics.SYB Data.Generics.Str Data.Generics.Uniplate
    Data.Generics.Uniplate.Data Data.Generics.Uniplate.Data.Instances
    Data.Generics.Uniplate.DataOnly Data.Generics.Uniplate.Direct
    Data.Generics.Uniplate.Operations Data.Generics.Uniplate.Typeable
    Data.Generics.Uniplate.Zipper Data.Generics.UniplateOn
    Data.Generics.UniplateStr Data.Generics.UniplateStrOn

hidden-modules:
    Data.Generics.Uniplate.Internal.Data
    Data.Generics.Uniplate.Internal.DataOnlyOperations
    Data.Generics.Uniplate.Internal.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/uniplate-1.6.13
library-dirs:         /usr/lib/ghc-8.10.3/site-local/uniplate-1.6.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/uniplate-1.6.13
hs-libraries:         HSuniplate-1.6.13-4aXpbfPDqvTD2bjR5AQQUf
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-prim-0.6.1
    hashable-1.3.0.0-AuOWFkmW3BKQo2eaHHrrX
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp
    unordered-containers-0.2.13.0-GkweYkpoMGZ8mML63K9Z6H

haddock-interfaces:   /usr/share/doc/haskell-uniplate/html/uniplate.haddock
haddock-html:         /usr/share/doc/haskell-uniplate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
